@@ -1,6 +1,6 @@
 package Catmandu::Exporter::BagIt;
 
-our $VERSION = '0.251';
+our $VERSION = '0.260';
 
 =head1 NAME
 
@@ -145,10 +145,7 @@ sub add {
                     or Catmandu::Error->throw("Could not create temp file");
 
             # For now using a simplistic mirror operation
-            my $fname    = $tmp->stringify . '_mirror'; # Use the tmp only as lock
-                                                        # name and create a non-existing
-                                                        # derivative name
-
+            my $fname    = $tmp->stringify;
             my $response = $bagit->user_agent->mirror($url,$fname);
 
             unless ($response->is_success) {
@@ -163,8 +160,6 @@ sub add {
             $bagit->write($directory, overwrite => 1);
 
             undef($tmp);
-
-            unlink($fname);
         }
     }
     if ( exists $data->{files} ) {
